Index: src/deoptimizer.h |
diff --git a/src/deoptimizer.h b/src/deoptimizer.h |
index 02449f1c7033a5200e18da2e6255597055504773..a0cc6975c3c95862cf284591d593124dd8995106 100644 |
--- a/src/deoptimizer.h |
+++ b/src/deoptimizer.h |
@@ -462,7 +462,7 @@ class FrameDescription { |
} |
uint32_t GetFrameSize() const { |
- ASSERT(static_cast<uint32_t>(frame_size_) == frame_size_); |
+ DCHECK(static_cast<uint32_t>(frame_size_) == frame_size_); |
return static_cast<uint32_t>(frame_size_); |
} |
@@ -491,11 +491,11 @@ class FrameDescription { |
intptr_t GetRegister(unsigned n) const { |
#if DEBUG |
// This convoluted ASSERT is needed to work around a gcc problem that |
// improperly detects an array bounds overflow in optimized debug builds |
// when using a plain ASSERT. |
if (n >= ARRAY_SIZE(registers_)) { |
- ASSERT(false); |
+ DCHECK(false); |
return 0; |
} |
#endif |
@@ -503,17 +503,17 @@ class FrameDescription { |
} |
double GetDoubleRegister(unsigned n) const { |
- ASSERT(n < ARRAY_SIZE(double_registers_)); |
+ DCHECK(n < ARRAY_SIZE(double_registers_)); |
return double_registers_[n]; |
} |
void SetRegister(unsigned n, intptr_t value) { |
- ASSERT(n < ARRAY_SIZE(registers_)); |
+ DCHECK(n < ARRAY_SIZE(registers_)); |
registers_[n] = value; |
} |
void SetDoubleRegister(unsigned n, double value) { |
- ASSERT(n < ARRAY_SIZE(double_registers_)); |
+ DCHECK(n < ARRAY_SIZE(double_registers_)); |
double_registers_[n] = value; |
} |
@@ -609,7 +609,7 @@ class FrameDescription { |
intptr_t frame_content_[1]; |
intptr_t* GetFrameSlotPointer(unsigned offset) { |
- ASSERT(offset < frame_size_); |
+ DCHECK(offset < frame_size_); |
return reinterpret_cast<intptr_t*>( |
reinterpret_cast<Address>(this) + frame_content_offset() + offset); |
} |
@@ -658,7 +658,7 @@ class TranslationIterator BASE_EMBEDDED { |
public: |
TranslationIterator(ByteArray* buffer, int index) |
: buffer_(buffer), index_(index) { |
- ASSERT(index >= 0 && index < buffer->length()); |
+ DCHECK(index >= 0 && index < buffer->length()); |
} |
int32_t Next(); |
@@ -930,13 +930,13 @@ class DeoptimizedFrameInfo : public Malloced { |
// Get an incoming argument. |
Object* GetParameter(int index) { |
- ASSERT(0 <= index && index < parameters_count()); |
+ DCHECK(0 <= index && index < parameters_count()); |
return parameters_[index]; |
} |
// Get an expression from the expression stack. |
Object* GetExpression(int index) { |
- ASSERT(0 <= index && index < expression_count()); |
+ DCHECK(0 <= index && index < expression_count()); |
return expression_stack_[index]; |
} |
@@ -947,13 +947,13 @@ class DeoptimizedFrameInfo : public Malloced { |
private: |
// Set an incoming argument. |
void SetParameter(int index, Object* obj) { |
- ASSERT(0 <= index && index < parameters_count()); |
+ DCHECK(0 <= index && index < parameters_count()); |
parameters_[index] = obj; |
} |
// Set an expression on the expression stack. |
void SetExpression(int index, Object* obj) { |
- ASSERT(0 <= index && index < expression_count()); |
+ DCHECK(0 <= index && index < expression_count()); |
expression_stack_[index] = obj; |
} |
@@ -491,11 +491,11 @@ class FrameDescription { |
intptr_t GetRegister(unsigned n) const { |
#if DEBUG |
- // This convoluted ASSERT is needed to work around a gcc problem that |
+ // This convoluted DCHECK is needed to work around a gcc problem that |
// improperly detects an array bounds overflow in optimized debug builds |
@@ -491,11 +491,11 @@ class FrameDescription { |
// improperly detects an array bounds overflow in optimized debug builds |
- // when using a plain ASSERT. |
+ // when using a plain DCHECK. |
if (n >= ARRAY_SIZE(registers_)) { |